# RBLX

RBLX is a Python library providing utilities for Roblox.

## Installation

```bash
pip install .
```

## Usage

```python
from rblx import get_username, greet

print(get_username(123))
print(greet("TuFueguito"))
```
